@@ -2,7 +2,7 @@
 # @Author: kt16
 # @Date:   2020-05-12 14:01:32
 # @Last Modified by:   Kelvin
-# @Last Modified time: 2020-12-14 03:22:29
+# @Last Modified time: 2021-02-18 23:53:56
 
 import sys
 import os
@@ -75,10 +75,10 @@ def dict_from_table(meta, columns):
         pandas dataframe or file path
     columns
         column names in dataframe
+    
     Returns
     -------
-    sample_dict
-        dictionary
+    dictionary
     """
     if (isinstance(meta, pd.DataFrame)) & (columns is not None):
         meta_ = meta
@@ -98,9 +98,10 @@ def clean_nan_dict(d):
     ----------
     d
         dictionary
+    
     Returns
     -------
-        dictionary with no NAs.
+    dictionary with no NAs.
     """
 
     return {
@@ -115,9 +116,10 @@ def flatten(l):
     ----------
     l
         list
+    
     Returns
     -------
-        a flattened list.
+    a flattened list.
     """
     for el in l:
         if isinstance(el, Iterable) and not isinstance(el, (str, bytes)):
@@ -126,6 +128,16 @@ def flatten(l):
             yield el
 
 def makeblastdb(ref):
+    """
+    Runs makeblastdb.
+
+    Parameters
+    ----------
+    ref
+        fasta file
+
+    """
+
     cmd = ['makeblastdb',
                '-dbtype', 'nucl',
                '-parse_seqids',
@@ -168,9 +180,10 @@ def load_data(obj):
     ----------
     obj : DataFrame, str
         file path to .tsv file or pandas DataFrame object.
+    
     Returns
     -------
-        pandas DataFrame object.
+    pandas DataFrame object.
     """
     if os.path.isfile(str(obj)):
         try:
@@ -196,9 +209,10 @@ def setup_metadata_(data):
     ----------
     data : DataFrame
         pandas DataFrame object.    
+    
     Returns
     -------
-        pandas DataFrame object.
+    pandas DataFrame object.
     """
     dat_h = data[data['locus'] == 'IGH'].copy()
     dict_h = dict(zip(dat_h['sequence_id'], dat_h['cell_id']))
@@ -215,9 +229,10 @@ def setup_metadata(data, clone_key = None):
         pandas DataFrame object.
     clone_key : str, optiona;
         column name of clone id. None defaults to 'clone_id'.
+    
     Returns
     -------
-        pandas DataFrame object.
+    pandas DataFrame object.
     """
     if clone_key is None:
         clonekey = 'clone_id'
@@ -308,6 +323,7 @@ def setup_metadata(data, clone_key = None):
 def retrieve_metadata(data, retrieve_id, split_heavy_light, collapse):
     """
     A Dandelion class subfunction to populate the `.metadata` slot.
+
     Parameters
     ----------
     data : DataFrame
@@ -318,9 +334,10 @@ def retrieve_metadata(data, retrieve_id, split_heavy_light, collapse):
         Returns the retrieval splitted into two column for heavy and light. Default is True. False combines the retrieval into a single column.
     collapse : bool
         Whether or not to collapse unique elements if duplicated. For example, different contigs and same sample id would then benefit from this option being set to True.
+
     Returns
     -------
-        A dictionary with keys as cell_ids and records as retrieved value.
+    A dictionary with keys as cell_ids and records as retrieved value.
     """
     dat_h = data[data['locus'] == 'IGH'].copy()
     dat_l = data[data['locus'].isin(['IGK', 'IGL'])].copy()
@@ -401,9 +418,10 @@ def update_metadata(self, retrieve = None, isotype_dict = None, split_heavy_ligh
         Whether or not to collapse unique elements if duplicated. For example, different contigs and same sample id would then benefit from this option being set to True.
     clones_sep : tuple[int, str]
         A tuple containing how the clone groups should be extracted. None defaults to (0, '_').
+    
     Returns
     -------
-        Dandelion object with `.metadata` slot initialized.
+    Dandelion object with `.metadata` slot initialized.
     """
     dat = load_data(self.data)
     for x in ['cell_id', 'locus', 'c_call', 'umi_count']:
@@ -608,9 +626,9 @@ def update_metadata(self, retrieve = None, isotype_dict = None, split_heavy_ligh
             except:
                 lv_ = self.metadata.at[i, 'v_call_light']
             try:
-                lj_ = self.metadata.at[i, 'v_call_light'].split('|')
+                lj_ = self.metadata.at[i, 'j_call_light'].split('|')
             except:
-                lv_ = self.metadata.at[i, 'v_call_light']
+                lj_ = self.metadata.at[i, 'j_call_light']
             multi_ = []
             if len(hv_) > 1:
                 multi_.append(['Multi_heavy_v'])
@@ -659,6 +677,12 @@ def update_metadata(self, retrieve = None, isotype_dict = None, split_heavy_ligh
                     raise KeyError('Unknown column : \'%s\' to retrieve.' % ret)
 
 class Dandelion:
+    """
+    Dandelion class object.
+
+    Main class object storing input/ouput slots for all functions.
+
+    """
     def __init__(self, data=None, metadata=None, germline = None, distance=None, edges=None, layout=None, graph=None, initialize = True, **kwargs):
         self.data = data
         self.metadata = metadata
@@ -716,6 +740,18 @@ class Dandelion:
         return self._gen_repr(self.n_obs, self.n_contigs)
 
     def copy(self):
+        """
+        Performs a deep copy of all slots in `dandelion` class.
+
+        Parameters
+        ----------
+        self : Dandelion
+            Dandelion object.        
+        
+        Returns
+        -------
+        a deep copy of `dandelion` class.
+        """
         return copy.deepcopy(self)
 
     def update_germline(self, corrected = None, germline = None, org = 'human'):
@@ -732,9 +768,10 @@ class Dandelion:
             path to germline database folder. Defaults to `$GERMLINE` environmental variable.
         org : str
             organism of reference folder. Default is 'human'.
+        
         Returns
         -------
-            updated germline reference diciontary in `.germline` slot.
+        updated germline reference diciontary in `.germline` slot.
         """
         start = logg.info('Updating germline reference')
         env = os.environ.copy()
@@ -790,6 +827,7 @@ class Dandelion:
     def write_pkl(self, filename='dandelion_data.pkl.pbz2', **kwargs):
         """
         Writes a `Dandelion` class to .pkl format.
+
         Parameters
         ----------
         filename
@@ -819,6 +857,7 @@ class Dandelion:
     def write_h5(self, filename='dandelion_data.h5', complib = None, compression = None, compression_level = None, **kwargs):
         """
         Writes a `Dandelion` class to .h5 format.
+
         Parameters
         ----------
         filename
@@ -937,6 +976,7 @@ def isBZIP(filename):
 def read_pkl(filename='dandelion_data.pkl.pbz2'):
     """
     Reads in and returns a `Dandelion` class saved using pickle format.
+
     Parameters
     ----------
     filename
@@ -944,7 +984,7 @@ def read_pkl(filename='dandelion_data.pkl.pbz2'):
 
     Returns
     -------
-       Dandelion object.
+    Dandelion object.
     """
     if isBZIP(filename):
         data = bz2.BZ2File(filename, 'rb')
@@ -960,6 +1000,7 @@ def read_pkl(filename='dandelion_data.pkl.pbz2'):
 def read_h5(filename='dandelion_data.h5'):
     """
     Reads in and returns a `Dandelion` class from .h5 format.
+
     Parameters
     ----------
     filename
@@ -967,7 +1008,7 @@ def read_h5(filename='dandelion_data.h5'):
 
     Returns
     -------
-       Dandelion object.
+    Dandelion object.
     """    
     try:
         data = pd.read_hdf(filename, 'data')
@@ -1061,13 +1102,15 @@ def read_h5(filename='dandelion_data.h5'):
 
 def concat(arrays, check_unique = False):
     """
-    Generates a dictionary from a dataframe
+    Concatenate dataframe and return as Dandelion object.
+
     Parameters
     ----------
-    meta
+    arrays
         pandas dataframe or file path
     columns
         column names in dataframe
+    
     Returns
     -------
     sample_dict
